## Usage

```python
from shortlink import short
short.cuttly("link!name")
short.isgd("link")
short.dagd("link")

//example

short.cuttly("google.com!goodness")
short.isgd("google.com")
short.dagd("google.com")
```
